@@ -19,6 +19,33 @@ def main():
     parser.add_argument(
         '--search', nargs='*', help='Monitor only runs that satisfy these criteria', default=[]
     )
+    parser.add_argument(
+        '--verbose', action='store_true', help='Whether to print out extra information'
+    )
+    parser.add_argument(
+        '--sleep-time', help='Number of seconds to wait between checks', default=5, type=int
+    )
+    parser.add_argument(
+        '--restart-after-seconds',
+        type=int,
+        help='Restart the worker manager after this many seconds have passed since launch',
+    )
+    parser.add_argument(
+        '--no-prefilter',
+        action='store_true',
+        help='If set, do not filter run bundles by whether the created workers satisfy their requested resources.',
+    )
+    parser.add_argument(
+        '--once',
+        help='Just run once and exit instead of looping (for debugging)',
+        action='store_true',
+    )
+    parser.add_argument(
+        '--min-seconds-between-workers',
+        help='Minimum time to wait between launching workers',
+        default=1 * 60,
+        type=int,
+    )
     parser.add_argument('--worker-tag', help='Tag to look for and put on workers')
     parser.add_argument(
         '--worker-work-dir-prefix', help="Prefix to use for each worker's working directory."
@@ -31,34 +58,12 @@ def main():
         action='store_true',
         help="Delete a worker's working directory when the worker process exits.",
     )
-    parser.add_argument(
-        '--verbose', action='store_true', help='Whether to print out extra information'
-    )
-    parser.add_argument(
-        '--sleep-time', help='Number of seconds to wait between checks', default=5, type=int
-    )
-    parser.add_argument(
-        '--restart-after-seconds',
-        type=int,
-        help='Restart the worker manager after this many seconds have passed since launch',
-    )
-    parser.add_argument(
-        '--once',
-        help='Just run once and exit instead of looping (for debugging)',
-        action='store_true',
-    )
     parser.add_argument(
         '--worker-idle-seconds',
         help='Workers wait this long for extra runs before quitting',
         default=10 * 60,
         type=int,
     )
-    parser.add_argument(
-        '--min-seconds-between-workers',
-        help='Minimum time to wait between launching workers',
-        default=1 * 60,
-        type=int,
-    )
     parser.add_argument(
         '--worker-checkin-frequency-seconds',
         type=int,
